;; Generated package description from lin.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "lin" "2.0.0.0.20260324.81759" "Make `hl-line-mode' more suitable for selection interfaces" '((emacs "27.1")) :commit "011cc169cea22f96191e53fbd66b76a357d4e601" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("convenience" "faces" "theme") :url "https://github.com/protesilaos/lin")
